
# Gestational Limits Per State
## Alabama
### Banned After Weeks Since Last Menstrual Period: 0
### Life Exception: True
### Health Exception: Physical
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: 2022-06-28T22:14:05.000Z
## Arizona
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: 2022-06-30T13:26:49.000Z
## Arkansas
### Banned After Weeks Since Last Menstrual Period: 0
### Life Exception: True
### Health Exception: No exception
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: 2022-06-24T18:39:14.000Z
## California
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Connecticut
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Delaware
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: Lethal fetal anomaly
### Rape or Incest Exception: No exception
### Last Updated: No date available
## District of Columbia
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Florida
### Banned After Weeks Since Last Menstrual Period: 15
### Life Exception: True
### Health Exception: Physical
### Fetal Health Exception: Lethal fetal anomaly
### Rape or Incest Exception: No exception
### Last Updated: 2022-07-05T15:55:49.000Z
## Georgia
### Banned After Weeks Since Last Menstrual Period: 22
### Life Exception: True
### Health Exception: Physical
### Fetal Health Exception: Lethal fetal anomaly
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Hawaii
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Idaho
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: No exception
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Illinois
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Indiana
### Banned After Weeks Since Last Menstrual Period: 22
### Life Exception: True
### Health Exception: Physical
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Iowa
### Banned After Weeks Since Last Menstrual Period: 22
### Life Exception: True
### Health Exception: Physical
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Kansas
### Banned After Weeks Since Last Menstrual Period: 22
### Life Exception: True
### Health Exception: Physical
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Kentucky
### Banned After Weeks Since Last Menstrual Period: 22
### Life Exception: True
### Health Exception: Physical
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: 2022-06-30T14:01:14.000Z
## Louisiana
### Banned After Weeks Since Last Menstrual Period: 22
### Life Exception: True
### Health Exception: Physical
### Fetal Health Exception: Lethal fetal anomaly
### Rape or Incest Exception: No exception
### Last Updated: 2022-06-27T18:06:17.000Z
## Maine
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Maryland
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: Serious fetal anomaly
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Massachusetts
### Banned After Weeks Since Last Menstrual Period: 24
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: Lethal fetal anomaly
### Rape or Incest Exception: No exception
### Last Updated: 2022-06-30T09:58:24.000Z
## Michigan
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: No exception
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Minnesota
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Mississippi
### Banned After Weeks Since Last Menstrual Period: 20
### Life Exception: True
### Health Exception: Major Bodily Function
### Fetal Health Exception: Serious fetal anomaly
### Rape or Incest Exception: No exception
### Last Updated: 2022-06-27T13:29:59.000Z
## Missouri
### Banned After Weeks Since Last Menstrual Period: 0
### Life Exception: True
### Health Exception: Physical
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: 2022-06-24T15:19:57.000Z
## Montana
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: Major Bodily Function
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Nebraska
### Banned After Weeks Since Last Menstrual Period: 22
### Life Exception: True
### Health Exception: Physical
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Nevada
### Banned After Weeks Since Last Menstrual Period: 24
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## New Hampshire
### Banned After Weeks Since Last Menstrual Period: 24
### Life Exception: True
### Health Exception: Physical
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: 2022-02-11T15:50:11.000Z
## New York
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## North Carolina
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: 2019-11-13T12:12:09.000Z
## North Dakota
### Banned After Weeks Since Last Menstrual Period: 22
### Life Exception: True
### Health Exception: Physical
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Ohio
### Banned After Weeks Since Last Menstrual Period: 6
### Life Exception: True
### Health Exception: Physical
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: 2022-06-24T22:39:26.000Z
## Oklahoma
### Banned After Weeks Since Last Menstrual Period: 0
### Life Exception: True
### Health Exception: No exception
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: 2022-06-24T18:35:26.000Z
## Pennsylvania
### Banned After Weeks Since Last Menstrual Period: 24
### Life Exception: True
### Health Exception: Major Bodily Function
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Rhode Island
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: No exception
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: 2019-07-02T11:33:41.000Z
## South Carolina
### Banned After Weeks Since Last Menstrual Period: 6
### Life Exception: True
### Health Exception: Physical
### Fetal Health Exception: Lethal fetal anomaly
### Rape or Incest Exception: True
### Last Updated: 2022-06-27T22:30:55.000Z
## South Dakota
### Banned After Weeks Since Last Menstrual Period: 0
### Life Exception: True
### Health Exception: No exception
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: 2022-06-24T14:47:55.000Z
## Tennessee
### Banned After Weeks Since Last Menstrual Period: 6
### Life Exception: True
### Health Exception: Physical
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: 2022-06-28T16:54:23.000Z
## Texas
### Banned After Weeks Since Last Menstrual Period: 0
### Life Exception: True
### Health Exception: No exception
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: 2022-07-02T10:05:28.000Z
## Utah
### Banned After Weeks Since Last Menstrual Period: 18
### Life Exception: True
### Health Exception: Major Bodily Function
### Fetal Health Exception: Lethal fetal anomaly
### Rape or Incest Exception: True
### Last Updated: 2022-07-01T19:52:54.000Z
## Virginia
### Banned After Weeks Since Last Menstrual Period: 26
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: 2022-02-15T21:04:54.000Z
## Washington
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## West Virginia
### Banned After Weeks Since Last Menstrual Period: 22
### Life Exception: True
### Health Exception: Physical
### Fetal Health Exception: Lethal fetal anomaly
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Wisconsin
### Banned After Weeks Since Last Menstrual Period: 22
### Life Exception: True
### Health Exception: Major Bodily Function
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available
## Wyoming
### Banned After Weeks Since Last Menstrual Period: 99
### Life Exception: True
### Health Exception: Any
### Fetal Health Exception: No exception
### Rape or Incest Exception: No exception
### Last Updated: No date available